package de.wim.outldd.examples;

import java.io.File;

import de.wim.outldd.OutlookDD;
import javafx.application.Application;
import javafx.event.EventHandler;
import javafx.scene.Scene;
import javafx.scene.control.Alert;
import javafx.scene.control.Label;
import javafx.scene.control.Alert.AlertType;
import javafx.scene.input.DragEvent;
import javafx.scene.input.Dragboard;
import javafx.scene.input.TransferMode;
import javafx.scene.layout.VBox;
import javafx.stage.Stage;

public class DragDropExampleFX extends Application {

	public static boolean initOutlDD() {
		// Optional: set a log file for the native library
		OutlookDD.setLogFile(new File("d:\\temp\\log\\outldd.log"), true);

		// Only this line is required to support D&D from Outlook
		OutlookDD.init(OutlookDD.MODE_TEMP_FILES);

		return true;
	}

	public static void main(String[] args) {
		Application.launch(args);
	}

	@Override
	public void start(Stage primaryStage) {

		// Initialize OutlDD after the toolkit is initialized
		// in order to support JavaFX packaged applications.
		initOutlDD();

		VBox root = new VBox();
		Label label = new Label();
		label.setText("Drop mails here");
		root.getChildren().add(label);

		Scene scene = new Scene(root, 551, 400);

		scene.setOnDragOver(new EventHandler<DragEvent>() {
			public void handle(DragEvent event) {
				Dragboard db = event.getDragboard();
				if (db.hasFiles()) {
					event.acceptTransferModes(TransferMode.COPY);
				} else {
					event.consume();
				}
			}
		});

		// Dropping over surface
		scene.setOnDragDropped(new EventHandler<DragEvent>() {
			public void handle(DragEvent event) {
				Dragboard db = event.getDragboard();
				boolean success = false;
				if (db.hasFiles()) {
					StringBuilder sbuf = new StringBuilder();

					success = true;
					String filePath = null;
					for (File file : db.getFiles()) {
						filePath = file.getAbsolutePath();
						System.out.println(filePath);
						sbuf.append(file).append("\n");
					}

					Alert alert = new Alert(AlertType.INFORMATION, sbuf.toString());
					alert.showAndWait();
				}
				event.setDropCompleted(success);
				event.consume();
			}
		});

		primaryStage.setScene(scene);
		primaryStage.show();
	}
}
