/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */

package de.wim.outldd.examples;
import java.io.File;
import java.io.IOException;
import java.util.List;
import java.util.concurrent.CountDownLatch;

import javax.swing.SwingUtilities;

import de.wim.outldd.OutlookDD;
import de.wim.outldd.OutlookData;
import de.wim.outldd.OutlookItem;
import de.wim.outldd.OutlookMsgItem;
import de.wim.outldd.OutlookMsgProperties;
import javafx.application.Application;
import javafx.application.Platform;
import javafx.event.EventHandler;
import javafx.scene.Scene;
import javafx.scene.control.Alert;
import javafx.scene.control.Alert.AlertType;
import javafx.scene.control.Label;
import javafx.scene.input.DragEvent;
import javafx.scene.input.Dragboard;
import javafx.scene.input.TransferMode;
import javafx.scene.layout.VBox;
import javafx.stage.Stage;

/**
 *
 * @author Imig
 */
public class DragDropExampleMemFX extends Application {
    
    public static boolean initOutlDD() {
        // Optional: set a log file for the native library
        OutlookDD.setLogFile(new File("d:\\temp\\outldd\\outldd.log"), true);

        //Optional: set a directory to be used for temporary files
        OutlookDD.setTempDir(new File("d:\\temp\\outldd"));

        // Only this line is required to support D&D from Outlook
        OutlookDD.init(OutlookDD.MODE_MEMORY_STREAMS);

        return true;
    }

    public static void main(String[] args) {
        Application.launch(args);
    }

    @Override
    public void start(Stage primaryStage) {
    	
    	// Initialize OutlDD after the toolkit is initialized
    	// in order to support JavaFX packaged applications.
    	initOutlDD();
    	
    	primaryStage.setTitle("DragDropExampleMemFX");
    	   
        VBox root = new VBox();
        Label label = new Label();
        label.setText("Drop mails here");
        root.getChildren().add(label);
        
        Scene scene = new Scene(root, 551, 400);
        scene.setOnDragOver(new EventHandler<DragEvent>() {
			public void handle(DragEvent event) {
                if (OutlookDD.isDataAvail()) { // true, if this is a D&D operation from Outlook 
                    event.acceptTransferModes(TransferMode.COPY);
                } else {
                    Dragboard db = event.getDragboard();
                    if (db.hasFiles()) {
                        event.acceptTransferModes(TransferMode.COPY);
                    } else {
                        event.consume();
                    }
                }
			}

         });

        // Dropping over surface
        scene.setOnDragDropped(new EventHandler<DragEvent>() {
            public void handle(DragEvent event) {
                Dragboard db = event.getDragboard();
                boolean success = false;

                if (OutlookDD.isDataAvail()) { // true, if this is a D&D operation from Outlook
                    try {
                        OutlookData outlData = OutlookDD.getData();
                        handleOutlookData(outlData);
                    } finally {
                        OutlookDD.release();
                    }
                } else if (db.hasFiles()) {
                    success = true;
                    String filePath = null;
                    for (File file : db.getFiles()) {
                        filePath = file.getAbsolutePath();
                        System.out.println(filePath);
                    }
                }

                event.setDropCompleted(success);
                event.consume();
            }

        });

        primaryStage.setScene(scene);

        primaryStage.show();
    }

    private void handleOutlookData(OutlookData outlData) {
        List<? extends OutlookItem> items = outlData.getItems();
        if (items.size() != 0) {
        	final StringBuilder sbuf = new StringBuilder();
        	try {
        		
            	for (OutlookItem item : items) {

            		File file = new File(System.getProperty("java.io.tmpdir"), item.getFileName());
            		System.out.println("oitem.class=" + item.getClass().getName() + ", value=" + item + ", file=" + file);

            		// Save the Outlook item to a temporary file
            		try {
            			item.saveContent(file);
            		}
            		catch (IOException e) {
            			e.printStackTrace();
            		}

        // ... Or call fitem.getContent() to get an InputStream
//        {
//	        FileOutputStream fos = null;
//	        InputStream is = null;
//	        try {
//	        	fos = new FileOutputStream(file);
//	        	is = item.getContent();
//		        byte[] buf = new byte[100*1000];
//		        int n = 0;
//		        while ((n = is.read(buf)) >= 0) {
//		        	fos.write(buf, 0, n);
//		        }
//	        }
//	        finally {
//	        	if (is != null) try { is.close(); } catch (Exception ignored) {}
//	        	if (fos != null) try { fos.close(); } catch (Exception ignored) {}
//	        }
//        }
	                // print mail properties
	                if (item instanceof OutlookMsgItem) {
	                    OutlookMsgItem msg = (OutlookMsgItem) item;
	                    OutlookMsgProperties props = msg.getProperties();
	                    System.out.println("from=" + props.getFrom()
	                            + ", subject=" + props.getSubject()
	                            + ", received=" + props.getReceived());
	                }
	                
	                sbuf.append(file).append("\n");
	            }
            	
	            Alert alert = new Alert(AlertType.INFORMATION, sbuf.toString());
	            alert.showAndWait();

        	}
        	catch (Exception e) {
        		e.printStackTrace();
        	}
        }
    }
    
}
