/*******************************************************************************
 * Copyright (c) 2000, 2004 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *******************************************************************************/
package org.eclipse.swt.snippets;

/*
 * Drag and Drop example snippet: determine data types available (win32 only)
 * NOTE: This snippet uses internal SWT packages that are
 * subject to change without notice.
 *
 * For a list of all SWT example snippets see
 * http://www.eclipse.org/swt/snippets/
 */
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;
import java.util.List;

import org.eclipse.swt.SWT;
import org.eclipse.swt.dnd.ByteArrayTransfer;
import org.eclipse.swt.dnd.DND;
import org.eclipse.swt.dnd.DropTarget;
import org.eclipse.swt.dnd.DropTargetAdapter;
import org.eclipse.swt.dnd.DropTargetEvent;
import org.eclipse.swt.dnd.FileTransfer;
import org.eclipse.swt.dnd.Transfer;
import org.eclipse.swt.dnd.TransferData;
import org.eclipse.swt.internal.ole.win32.COM;
import org.eclipse.swt.internal.win32.TCHAR;
import org.eclipse.swt.layout.FillLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Table;
import org.eclipse.swt.widgets.TableItem;

import de.wim.outldd.HGlobalInputStream;
import de.wim.outldd.OutlookDD;
import de.wim.outldd.OutlookData;
import de.wim.outldd.OutlookItem;
import de.wim.outldd.OutlookMsgItem;
import de.wim.outldd.OutlookMsgProperties;

public class Snippet83_MemStrm extends ByteArrayTransfer {
	
  private static Snippet83_MemStrm _instance = new Snippet83_MemStrm();
  private int[] ids;
  private String[] names;

  public static void main(String[] args) {
    OutlookDD.setLogFile(new File("d:\\temp\\outldd\\outldd.log"), true);
    OutlookDD.init(OutlookDD.MODE_MEMORY_STREAMS);
    
    final Display display = new Display();
    Shell shell = new Shell(display);
    shell.setLayout(new FillLayout());
    
    final Table control = new Table(shell, SWT.NONE);
    TableItem item = new TableItem(control, SWT.NONE);
    item.setText("Drag data over this site to see the native transfer type.");
    
    final Button button = new Button(shell, SWT.NONE);
    button.setText("Click and check the console");
    button.setVisible(false);
    button.addListener(SWT.MouseDown, new Listener() {
      public void handleEvent(Event e) {
        switch (e.type) {
        case SWT.MouseDown:
          System.out.println("Button pressed");
          break;
        }
      }
    });
    
    DropTarget target = new DropTarget(control, DND.DROP_DEFAULT | DND.DROP_COPY | DND.DROP_LINK | DND.DROP_MOVE);
    target.setTransfer(new Transfer[] { FileTransfer.getInstance(), Snippet83_MemStrm.getInstance()	});

    target.addDropListener(new DropTargetAdapter() {
    	
      public void dragEnter(DropTargetEvent event) {
        String ops = "";
        if ((event.operations & DND.DROP_COPY) != 0)
          ops += "Copy;";
        if ((event.operations & DND.DROP_MOVE) != 0)
          ops += "Move;";
        if ((event.operations & DND.DROP_LINK) != 0)
          ops += "Link;";
        control.removeAll();
        TableItem item1 = new TableItem(control, SWT.NONE);
        item1.setText("Allowed Operations are " + ops);

        if (event.detail == DND.DROP_DEFAULT) {
          if ((event.operations & DND.DROP_COPY) != 0) {
            event.detail = DND.DROP_COPY;
          } else if ((event.operations & DND.DROP_LINK) != 0) {
            event.detail = DND.DROP_LINK;
          } else if ((event.operations & DND.DROP_MOVE) != 0) {
            event.detail = DND.DROP_MOVE;
          }
        }

//        if (OutlookDD.isDataAvail()) {
//          TableItem item2 = new TableItem(control, SWT.NONE);
//          item2.setText("Data from OutlDD");
//        }
//        else 
        {
          TransferData[] data = event.dataTypes;
          for (int i = 0; i < data.length; i++) {
            int id = data[i].type;
            TableItem item2 = new TableItem(control, SWT.NONE);
            item2.setText("Data type is " + id);
          }
        }        
        
        System.out.println("dragEnter=" + event);
      }
      
      @Override
    	public void dropAccept(DropTargetEvent event) {
          System.out.println("dropAccept=" + event);
    		super.dropAccept(event);
    	}
      
      @Override
    	public void dragLeave(DropTargetEvent event) {
          System.out.println("dragLeave=" + event);
          //button.notifyListeners( SWT.MouseDown, null );
          
          Event e = new Event();
          e.type = SWT.MouseDown;
          e.button = 1;
          display.post(e);
          
   		super.dragLeave(event);
    	}

      @Override
    	public void dragOperationChanged(DropTargetEvent event) {
          System.out.println("dragOperationChanged=" + event);
    		super.dragOperationChanged(event);
    	}
      
      @Override
    	public void dragOver(DropTargetEvent event) {
//          System.out.println("dragOver=" + event);
//    		super.dragOver(event);
    	}
      
      public void drop(DropTargetEvent event){
          System.out.println("drop=" + event);
        
        if (OutlookDD.isDataAvail()) { // true, if this is a D&D operation from Outlook
          try {
            OutlookData outlData = OutlookDD.getData();
            List<? extends OutlookItem> items = outlData.getItems();
            if (items.size() != 0) {
              for (OutlookItem item : items) {
            	  
                // Save the Outlook item to a temporary file (1) or get content stream (2).
            	  

                // (1) Save the Outlook item to a temporary file:
            	// {
                //   File file = new File(System.getProperty("java.io.tmpdir"), item.getFileName());
                //   item.saveContent(file);
                //   System.out.println("oitem.class=" + item.getClass().getName() + ", value=" + item + ", file=" + file);
            	// }
            	  
            	// (2) Get content stream and e.g. save to temporary file:
            	{
            		File file = new File(System.getProperty("java.io.tmpdir"), item.getFileName());
            		HGlobalInputStream inputStream = ((HGlobalInputStream) item.getContent());
						
					System.out.println("content length=" + inputStream.available());
					
					// write the inputStream to a FileOutputStream
					OutputStream out = new FileOutputStream(file);
					
					int read = 0;
					byte[] bytes = new byte[1024];
					
					while ((read = inputStream.read(bytes)) != -1) {
						out.write(bytes, 0, read);
					}
					
					inputStream.close();
					out.flush();
					out.close();
            	}
            	
                // print mail properties
                if (item instanceof OutlookMsgItem) {
                  OutlookMsgItem msg = (OutlookMsgItem)item;
                  OutlookMsgProperties props = msg.getProperties();
                  System.out.println("from=" + props.getFrom()
                      + ", subject=" + props.getSubject()
                      + ", received=" + props.getReceived());
                }
              }
            }
          } catch (IOException e) {
            e.printStackTrace();
          } finally {
            OutlookDD.release();
          }

        }
      }
    }
    
    );

    shell.setSize(400, 400);
    shell.open();
    while (!shell.isDisposed()) {
      if (!display.readAndDispatch())
        display.sleep();
    }
    display.dispose();
  }

  public static Snippet83_MemStrm getInstance() {
    return _instance;
  }

  Snippet83_MemStrm() {

	  names = new String[] { "FileGroupDescriptor", "FileGroupDescriptorW" };
	  ids = new int[names.length];
	  
	  for (int i = 0; i < names.length; i++) {
		  TCHAR szFormat1 = new TCHAR(0, names[i], true);
		  int fmt1 = COM.RegisterClipboardFormat(szFormat1);
		  ids[i] = fmt1;
	  }
	  
  }

  public void javaToNative(Object object, TransferData transferData) {
  }

  public Object nativeToJava(TransferData transferData) {
    return "ignored";
  }

  protected String[] getTypeNames() {
     return names;
  }

  protected int[] getTypeIds() {
     return ids;
  }

}